// src/contacts-v4-submit-contact-submitted-contact.universal.ts
import { transformError as sdkTransformError } from "@wix/sdk-runtime/transform-error";
import {
  renameKeysFromSDKRequestToRESTRequest,
  renameKeysFromRESTResponseToSDKResponse
} from "@wix/sdk-runtime/rename-all-nested-keys";

// src/contacts-v4-submit-contact-submitted-contact.http.ts
import { transformSDKFloatToRESTFloat } from "@wix/sdk-runtime/transformations/float";
import { transformSDKTimestampToRESTTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformPaths } from "@wix/sdk-runtime/transformations/transform-paths";
import { resolveUrl } from "@wix/sdk-runtime/rest-modules";
function resolveComWixpressContactsAllocatorApiV4ContactSubmitServiceV4Url(opts) {
  const domainToMappings = {
    "www.wixapis.com": [
      {
        srcPath: "/contacts/v4/contact-submit",
        destPath: "/v4/contact-submit"
      }
    ],
    "www._base_domain_": [
      {
        srcPath: "/_api/contacts/v4/contact-submit",
        destPath: "/v4/contact-submit"
      }
    ],
    "manage._base_domain_": [
      {
        srcPath: "/_api/contacts/v4/contact-submit",
        destPath: "/v4/contact-submit"
      }
    ],
    _: [
      {
        srcPath: "/_api/contacts/v4/contact-submit",
        destPath: "/v4/contact-submit"
      }
    ],
    "*.dev.wix-code.com": [
      {
        srcPath: "/_api/contacts/v4/contact-submit",
        destPath: "/v4/contact-submit"
      }
    ]
  };
  return resolveUrl(Object.assign(opts, { domainToMappings }));
}
var PACKAGE_NAME = "@wix/auto_sdk_crm_submitted-contact";
function submitContact(payload) {
  function __submitContact({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKFloatToRESTFloat,
        paths: [
          { path: "info.addresses.items.address.geocode.latitude" },
          { path: "info.addresses.items.address.geocode.longitude" }
        ]
      },
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [
          { path: "info.picture.image.urlExpirationDate" },
          { path: "activity.activityDate" },
          { path: "activity.date" }
        ]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.contacts.v4.submit_contact",
      method: "POST",
      methodFqn: "com.wixpress.contacts.allocator.api.v4.ContactSubmitServiceV4.SubmitContact",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressContactsAllocatorApiV4ContactSubmitServiceV4Url({
        protoPath: "/v4/contact-submit",
        data: serializedData,
        host
      }),
      data: serializedData
    };
    return metadata;
  }
  return __submitContact;
}

// src/contacts-v4-submit-contact-submitted-contact.universal.ts
import { transformSDKAddressToRESTAddress } from "@wix/sdk-runtime/transformations/address";
import { transformSDKImageToRESTImage } from "@wix/sdk-runtime/transformations/image";
import { transformPaths as transformPaths2 } from "@wix/sdk-runtime/transformations/transform-paths";
var EmailTag = /* @__PURE__ */ ((EmailTag2) => {
  EmailTag2["UNTAGGED"] = "UNTAGGED";
  EmailTag2["MAIN"] = "MAIN";
  EmailTag2["HOME"] = "HOME";
  EmailTag2["WORK"] = "WORK";
  return EmailTag2;
})(EmailTag || {});
var PhoneTag = /* @__PURE__ */ ((PhoneTag2) => {
  PhoneTag2["UNTAGGED"] = "UNTAGGED";
  PhoneTag2["MAIN"] = "MAIN";
  PhoneTag2["HOME"] = "HOME";
  PhoneTag2["MOBILE"] = "MOBILE";
  PhoneTag2["WORK"] = "WORK";
  PhoneTag2["FAX"] = "FAX";
  return PhoneTag2;
})(PhoneTag || {});
var AddressTag = /* @__PURE__ */ ((AddressTag2) => {
  AddressTag2["UNTAGGED"] = "UNTAGGED";
  AddressTag2["HOME"] = "HOME";
  AddressTag2["WORK"] = "WORK";
  AddressTag2["BILLING"] = "BILLING";
  AddressTag2["SHIPPING"] = "SHIPPING";
  return AddressTag2;
})(AddressTag || {});
var SubdivisionType = /* @__PURE__ */ ((SubdivisionType2) => {
  SubdivisionType2["UNKNOWN_SUBDIVISION_TYPE"] = "UNKNOWN_SUBDIVISION_TYPE";
  SubdivisionType2["ADMINISTRATIVE_AREA_LEVEL_1"] = "ADMINISTRATIVE_AREA_LEVEL_1";
  SubdivisionType2["ADMINISTRATIVE_AREA_LEVEL_2"] = "ADMINISTRATIVE_AREA_LEVEL_2";
  SubdivisionType2["ADMINISTRATIVE_AREA_LEVEL_3"] = "ADMINISTRATIVE_AREA_LEVEL_3";
  SubdivisionType2["ADMINISTRATIVE_AREA_LEVEL_4"] = "ADMINISTRATIVE_AREA_LEVEL_4";
  SubdivisionType2["ADMINISTRATIVE_AREA_LEVEL_5"] = "ADMINISTRATIVE_AREA_LEVEL_5";
  SubdivisionType2["COUNTRY"] = "COUNTRY";
  return SubdivisionType2;
})(SubdivisionType || {});
var ImageProvider = /* @__PURE__ */ ((ImageProvider2) => {
  ImageProvider2["UNKNOWN"] = "UNKNOWN";
  ImageProvider2["EXTERNAL"] = "EXTERNAL";
  ImageProvider2["WIX_MEDIA"] = "WIX_MEDIA";
  return ImageProvider2;
})(ImageProvider || {});
var ContactActivityType = /* @__PURE__ */ ((ContactActivityType2) => {
  ContactActivityType2["GENERAL"] = "GENERAL";
  ContactActivityType2["CONTACT_CREATED"] = "CONTACT_CREATED";
  ContactActivityType2["MEMBER_LOGIN"] = "MEMBER_LOGIN";
  ContactActivityType2["MEMBER_REGISTER"] = "MEMBER_REGISTER";
  ContactActivityType2["MEMBER_STATUS_CHANGED"] = "MEMBER_STATUS_CHANGED";
  ContactActivityType2["FORM_SUBMITTED"] = "FORM_SUBMITTED";
  ContactActivityType2["INBOX_FORM_SUBMITTED"] = "INBOX_FORM_SUBMITTED";
  ContactActivityType2["INBOX_PAYMENT_REQUEST_PAID"] = "INBOX_PAYMENT_REQUEST_PAID";
  ContactActivityType2["INBOX_MESSAGE_TO_CUSTOMER"] = "INBOX_MESSAGE_TO_CUSTOMER";
  ContactActivityType2["INBOX_MESSAGE_FROM_CUSTOMER"] = "INBOX_MESSAGE_FROM_CUSTOMER";
  ContactActivityType2["NEWSLETTER_SUBSCRIPTION_FORM_SUBMITTED"] = "NEWSLETTER_SUBSCRIPTION_FORM_SUBMITTED";
  ContactActivityType2["NEWSLETTER_SUBSCRIPTION_UNSUBSCRIBE"] = "NEWSLETTER_SUBSCRIPTION_UNSUBSCRIBE";
  ContactActivityType2["ECOM_PURCHASE"] = "ECOM_PURCHASE";
  ContactActivityType2["ECOM_CART_ABANDON"] = "ECOM_CART_ABANDON";
  ContactActivityType2["ECOM_CHECKOUT_BUYER"] = "ECOM_CHECKOUT_BUYER";
  ContactActivityType2["BOOKINGS_APPOINTMENT"] = "BOOKINGS_APPOINTMENT";
  ContactActivityType2["HOTELS_RESERVATION"] = "HOTELS_RESERVATION";
  ContactActivityType2["HOTELS_PURCHASE"] = "HOTELS_PURCHASE";
  ContactActivityType2["HOTELS_CONFIRMATION"] = "HOTELS_CONFIRMATION";
  ContactActivityType2["HOTELS_CANCEL"] = "HOTELS_CANCEL";
  ContactActivityType2["VIDEO_PURCHASE"] = "VIDEO_PURCHASE";
  ContactActivityType2["VIDEO_RENT"] = "VIDEO_RENT";
  ContactActivityType2["CASHIER_BUTTON_PURCHASE"] = "CASHIER_BUTTON_PURCHASE";
  ContactActivityType2["ARENA_NEW_LEAD"] = "ARENA_NEW_LEAD";
  ContactActivityType2["EVENTS_RSVP"] = "EVENTS_RSVP";
  ContactActivityType2["INVOICE_PAY"] = "INVOICE_PAY";
  ContactActivityType2["INVOICE_OVERDUE"] = "INVOICE_OVERDUE";
  ContactActivityType2["PRICE_QUOTE_ACCEPT"] = "PRICE_QUOTE_ACCEPT";
  ContactActivityType2["PRICE_QUOTE_EXPIRE"] = "PRICE_QUOTE_EXPIRE";
  ContactActivityType2["RESTAURANTS_ORDER"] = "RESTAURANTS_ORDER";
  ContactActivityType2["RESTAURANTS_RESERVATION"] = "RESTAURANTS_RESERVATION";
  ContactActivityType2["SHOUTOUT_OPEN"] = "SHOUTOUT_OPEN";
  ContactActivityType2["SHOUTOUT_CLICK"] = "SHOUTOUT_CLICK";
  ContactActivityType2["CONTACT_MERGED"] = "CONTACT_MERGED";
  ContactActivityType2["NEWSLETTER_SUBSCRIPTION_SUBSCRIBE"] = "NEWSLETTER_SUBSCRIPTION_SUBSCRIBE";
  ContactActivityType2["NEWSLETTER_SUBSCRIPTION_PENDING"] = "NEWSLETTER_SUBSCRIPTION_PENDING";
  ContactActivityType2["NEWSLETTER_SUBSCRIPTION_NOT_SET"] = "NEWSLETTER_SUBSCRIPTION_NOT_SET";
  ContactActivityType2["PHONE_SUBSCRIPTION_SUBSCRIBE"] = "PHONE_SUBSCRIPTION_SUBSCRIBE";
  ContactActivityType2["PHONE_SUBSCRIPTION_PENDING"] = "PHONE_SUBSCRIPTION_PENDING";
  ContactActivityType2["PHONE_SUBSCRIPTION_NOT_SET"] = "PHONE_SUBSCRIPTION_NOT_SET";
  ContactActivityType2["PHONE_SUBSCRIPTION_UNSUBSCRIBE"] = "PHONE_SUBSCRIPTION_UNSUBSCRIBE";
  return ContactActivityType2;
})(ContactActivityType || {});
var IdentityType = /* @__PURE__ */ ((IdentityType2) => {
  IdentityType2["UNKNOWN"] = "UNKNOWN";
  IdentityType2["CONTACT"] = "CONTACT";
  IdentityType2["MEMBER"] = "MEMBER";
  IdentityType2["NOT_AUTHENTICATED_MEMBER"] = "NOT_AUTHENTICATED_MEMBER";
  return IdentityType2;
})(IdentityType || {});
var SubmitOperation = /* @__PURE__ */ ((SubmitOperation2) => {
  SubmitOperation2["UNKNOWN"] = "UNKNOWN";
  SubmitOperation2["CREATE"] = "CREATE";
  SubmitOperation2["UPDATE"] = "UPDATE";
  return SubmitOperation2;
})(SubmitOperation || {});
var ContactSourceType = /* @__PURE__ */ ((ContactSourceType2) => {
  ContactSourceType2["OTHER"] = "OTHER";
  ContactSourceType2["ADMIN"] = "ADMIN";
  ContactSourceType2["WIX_APP"] = "WIX_APP";
  ContactSourceType2["IMPORT"] = "IMPORT";
  ContactSourceType2["THIRD_PARTY"] = "THIRD_PARTY";
  ContactSourceType2["WIX_BOOKINGS"] = "WIX_BOOKINGS";
  ContactSourceType2["WIX_CHAT"] = "WIX_CHAT";
  ContactSourceType2["WIX_EMAIL_MARKETING"] = "WIX_EMAIL_MARKETING";
  ContactSourceType2["WIX_EVENTS"] = "WIX_EVENTS";
  ContactSourceType2["WIX_FORMS"] = "WIX_FORMS";
  ContactSourceType2["WIX_GROUPS"] = "WIX_GROUPS";
  ContactSourceType2["WIX_HOTELS"] = "WIX_HOTELS";
  ContactSourceType2["WIX_MARKET_PLACE"] = "WIX_MARKET_PLACE";
  ContactSourceType2["WIX_MUSIC"] = "WIX_MUSIC";
  ContactSourceType2["WIX_RESTAURANTS"] = "WIX_RESTAURANTS";
  ContactSourceType2["WIX_SITE_MEMBERS"] = "WIX_SITE_MEMBERS";
  ContactSourceType2["WIX_STORES"] = "WIX_STORES";
  ContactSourceType2["WIX_CODE"] = "WIX_CODE";
  ContactSourceType2["HOPP"] = "HOPP";
  return ContactSourceType2;
})(ContactSourceType || {});
var WebhookIdentityType = /* @__PURE__ */ ((WebhookIdentityType2) => {
  WebhookIdentityType2["UNKNOWN"] = "UNKNOWN";
  WebhookIdentityType2["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
  WebhookIdentityType2["MEMBER"] = "MEMBER";
  WebhookIdentityType2["WIX_USER"] = "WIX_USER";
  WebhookIdentityType2["APP"] = "APP";
  return WebhookIdentityType2;
})(WebhookIdentityType || {});
async function appendOrCreateContact(options) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = transformPaths2(
    renameKeysFromSDKRequestToRESTRequest({
      info: options?.info,
      passThroughData: options?.passThroughData,
      contactId: options?.contactId
    }),
    [
      {
        transformFn: transformSDKAddressToRESTAddress,
        paths: [{ path: "info.addresses.items.address" }]
      },
      {
        transformFn: transformSDKImageToRESTImage,
        paths: [{ path: "info.picture.image" }]
      }
    ]
  );
  const reqOpts = submitContact(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          info: "$[0].info",
          passThroughData: "$[0].passThroughData",
          contactId: "$[0].contactId"
        },
        singleArgumentUnchanged: false
      },
      ["options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
export {
  AddressTag,
  ContactActivityType,
  ContactSourceType,
  EmailTag,
  IdentityType,
  ImageProvider,
  PhoneTag,
  SubdivisionType,
  SubmitOperation,
  WebhookIdentityType,
  appendOrCreateContact
};
//# sourceMappingURL=index.typings.mjs.map